/*
 * ODBC-Ruby binding
 * Copyright (c) 2001-2003 Christian Werner <chw@ch-werner.de>
 *
 * See the file "COPYING" for information on usage
 * and redistribution of this file and for a
 * DISCLAIMER OF ALL WARRANTIES.
 *
 * $Id: odbc.c,v 1.2 2003/05/21 13:27:55 chw Exp chw $
 */

#define UNICODE
#define _UNICODE

#include "../odbc.c"
